@@ -22,7 +22,7 @@ class AuxiliaryCoordinate(mixin.Coordinate,
     The auxiliary coordinate construct consists of a data array of the
     coordinate values which spans a subset of the domain axis
     constructs, an optional array of cell bounds recording the extents
-    of each cell (stored in a `cf.Bounds` object), and properties to
+    of each cell (stored in a `Bounds` object), and properties to
     describe the coordinates. An array of cell bounds spans the same
     domain axes as its coordinate array, with the addition of an extra
     dimension whose size is that of the number of vertices of each
@@ -38,6 +38,10 @@ class AuxiliaryCoordinate(mixin.Coordinate,
     `nc_set_variable`, `nc_get_variable`, `nc_del_variable` and
     `nc_has_variable` methods.
 
+    The netCDF variable group structure may be accessed with the
+    `nc_set_variable`, `nc_get_variable`, `nc_variable_groups`,
+    `nc_clear_variable_groups` and `nc_set_variable_groups` methods.
+
     '''
     def __repr__(self):
         '''Called by the `repr` built-in function.
@@ -47,20 +51,4 @@ class AuxiliaryCoordinate(mixin.Coordinate,
         '''
         return super().__repr__().replace('<', '<CF ', 1)
 
-    @property
-    def isauxiliary(self):
-        '''True, denoting that the variable is a aucilliary coordinate object.
-
-    .. seealso::`isdimension`, `isdomainancillary`,
-                `isfieldancillary`, `ismeasure`
-
-    **Examples:**
-
-    >>> c.isauxiliary
-    True
-
-        '''
-        return True
-
-
 # --- End: class
