@@ -1,13 +1,16 @@
 from .units import Units
 
-import sys
+import logging
 
+from enum     import Enum
 from psutil   import virtual_memory
 from tempfile import gettempdir
 
 from numpy.ma import masked as numpy_ma_masked
 from numpy.ma import nomask as numpy_ma_nomask
 
+import cfdm
+
 from . import mpi_on
 from . import mpi_size
 if mpi_on:
@@ -46,11 +49,13 @@ Whilst the dictionary may be modified directly, it is safer to
 retrieve and set the values with a function where one is
 provided. This is due to interdependencies between some values.
 
-:Keys:
+Note ATOL and RTOL are constants that in essence belong in this
+dict, but since they can be read and manipulated directly from cfdm,
+it is safest to work with cfdm.constants.CONSTANTS['ATOL'] (and
+'RTOL' equivalent) instead of storing separately and synchronising
+them here in cf.
 
-    ATOL : float
-      The value of absolute tolerance for testing numerically
-      tolerant equality.
+:Keys:
 
     TOTAL_MEMORY : float
       Find the total amount of physical memory (in bytes).
@@ -73,10 +78,6 @@ provided. This is due to interdependencies between some values.
       files which may be used for files containing data
       arrays.
 
-    RTOL : float
-      The value of relative tolerance for testing numerically
-      tolerant equality.
-
     TEMPDIR : str
       The location to store temporary files. By default it is
       the default directory used by the :mod:`tempfile` module.
@@ -96,20 +97,23 @@ provided. This is due to interdependencies between some values.
       this is 0 to try and automatically determine which mode to
       use.
 
+    LOG_LEVEL : str
+      The minimal level of seriousness for which log messages are shown.
+      See cf.log_level().
 """
 CONSTANTS = {
-    'RTOL'                  : sys.float_info.epsilon,
-    'ATOL'                  : sys.float_info.epsilon,
-    'TEMPDIR'               : gettempdir(),
-    'OF_FRACTION'           : 0.5,
-    'TOTAL_MEMORY'          : _TOTAL_MEMORY,
-    'FREE_MEMORY_FACTOR'    : 0.1,
-    'WORKSPACE_FACTOR_1'    : 2.0,
-    'WORKSPACE_FACTOR_2'    : 8.0,
-    'REGRID_LOGGING'        : False,
+    # See cfdm.constants.CONSTANTS for effective 'ATOL' and 'RTOL' values
+    'TEMPDIR': gettempdir(),
+    'OF_FRACTION': 0.5,
+    'TOTAL_MEMORY': _TOTAL_MEMORY,
+    'FREE_MEMORY_FACTOR': 0.1,
+    'WORKSPACE_FACTOR_1': 2.0,
+    'WORKSPACE_FACTOR_2': 8.0,
+    'REGRID_LOGGING': False,
     'COLLAPSE_PARALLEL_MODE': 0,
-    'RELAXED_IDENTITIES'    : False,
-    'IGNORE_IDENTITIES'     : False,
+    'RELAXED_IDENTITIES': False,
+    # 'IGNORE_IDENTITIES': False,  # no longer used
+    'LOG_LEVEL': logging.getLevelName(logging.getLogger().level),
 }
 
 CONSTANTS['FM_THRESHOLD'] = (
@@ -143,25 +147,25 @@ _stash2standard_name = {}
 # Coordinate reference constants TODO: turn these into functions
 # ---------------------------------------------------------------------
 cr_canonical_units = {
-    'earth_radius'                         : Units('m'),
-    'false_easting'                        : Units('m'),
-    'projection_x_coordinate'              : Units('m'),
-    'false_northing'                       : Units('m'),
-    'projection_y_coordinate'              : Units('m'),
-    'grid_north_pole_latitude'             : Units('degrees_north'),
-    'grid_north_pole_longitude'            : Units('degrees_east'),
-    'inverse_flattening'                   : Units('1'),
-    'latitude_of_projection_origin'        : Units('degrees_north'),
-    'longitude_of_central_meridian'        : Units('degrees_east'),
-    'longitude_of_prime_meridian'          : Units('degrees_east'),
-    'longitude_of_projection_origin'       : Units('degrees_east'),
-    'north_pole_grid_longitude'            : Units('degrees'),
-    'perspective_point_height'             : Units('m'),
-    'scale_factor_at_central_meridian'     : Units('1'),
-    'scale_factor_at_projection_origin'    : Units('1'),
-    'semi_major_axis'                      : Units('m'),
-    'semi_minor_axis'                      : Units('m'),
-    'standard_parallel'                    : Units('degrees_north'),
+    'earth_radius': Units('m'),
+    'false_easting': Units('m'),
+    'projection_x_coordinate': Units('m'),
+    'false_northing': Units('m'),
+    'projection_y_coordinate': Units('m'),
+    'grid_north_pole_latitude': Units('degrees_north'),
+    'grid_north_pole_longitude': Units('degrees_east'),
+    'inverse_flattening': Units('1'),
+    'latitude_of_projection_origin': Units('degrees_north'),
+    'longitude_of_central_meridian': Units('degrees_east'),
+    'longitude_of_prime_meridian': Units('degrees_east'),
+    'longitude_of_projection_origin': Units('degrees_east'),
+    'north_pole_grid_longitude': Units('degrees'),
+    'perspective_point_height': Units('m'),
+    'scale_factor_at_central_meridian': Units('1'),
+    'scale_factor_at_projection_origin': Units('1'),
+    'semi_major_axis': Units('m'),
+    'semi_minor_axis': Units('m'),
+    'standard_parallel': Units('degrees_north'),
     'straight_vertical_longitude_from_pole': Units('degrees_north'),
 }
 
@@ -313,3 +317,15 @@ cr_default_values = {
     'zsurf2': 0.0,
     'ztop': 0.0,
 }
+
+
+# --------------------------------------------------------------------
+# Logging level setup
+# --------------------------------------------------------------------
+# For explicitness, define here rather than importing identical Enum from cfdm
+class ValidLogLevels(Enum):
+    DISABLE = 0
+    WARNING = 1
+    INFO = 2
+    DETAIL = 3
+    DEBUG = -1
