@@ -1,4 +1,5 @@
 import atexit
+import logging
 
 from copy      import deepcopy
 from functools import reduce
@@ -31,8 +32,9 @@ from numpy.ma.core import MaskedConstant as numpy_ma_core_MaskedConstant
 # from cfunits import Units
 
 from ..units     import Units
-from ..functions import get_subspace, FREE_MEMORY, FM_THRESHOLD
-from ..functions import inspect as cf_inspect
+from ..functions import get_subspace, free_memory
+from ..functions import (inspect as cf_inspect,
+                         fm_threshold as cf_fm_threshold)
 from ..constants import CONSTANTS
 
 # from .filearray import  (_TempFileArray #, SharedMemoryArray,
@@ -41,6 +43,9 @@ from .cachedarray import CachedArray
 
 from .abstract import FileArray
 
+
+logger = logging.getLogger(__name__)
+
 _Units_conform = Units.conform
 
 _dtype_object = numpy_dtype(object)
@@ -321,7 +326,7 @@ class Partition:
                 if (FileArray is not None and isinstance(subarray, FileArray)):
                     try:
                         filename = subarray.get_filename()
-                    except:
+                    except Exception:
                         filename = None
 
                     if self.file_counter.get(filename, 999) <= 0:
@@ -329,7 +334,7 @@ class Partition:
                         # which is not referenced by any other
                         # partitions, so close the file.
                         subarray.close()
-            except:
+            except Exception:
                 # If we're here then it is likely that FileArray has been
                 # torn down, so just do nothing.
                 pass
@@ -406,7 +411,7 @@ class Partition:
                     not isinstance(subarray, CachedArray)):
                 try:
                     filename = subarray.get_filename()
-                except:
+                except Exception:
                     filename = None
 
                 if filename is None:
@@ -423,7 +428,7 @@ class Partition:
                     file_counter.pop(filename, None)
                 else:
                     file_counter[filename] = count
-        except:
+        except Exception:
             # If we're here then it is likely that FileArray has been
             # torn down, so just do nothing.
             pass
@@ -524,7 +529,6 @@ class Partition:
         '''
         return hasattr(self._subarray, '__array_interface__')
 
-
 #    @property
 #    def in_shared_memory(self):
 #        '''
@@ -778,11 +782,8 @@ class Partition:
         if kwargs:
             config.update(kwargs)
 
-        _debug = False
-
         original = getattr(self, '_original', None)
-        if _debug:
-            print('Partition.close: original =', original)
+        logger.partitioning('Partition.close: original = {}'.format(original))
 
         if not original:
             originally_on_disk = False
@@ -792,23 +793,19 @@ class Partition:
             original_subarray = original._subarray
 
         config = self.config
-        if _debug:
-            print(' config =', config)
+        logger.partitioning(' config = {}'.format(config))
 
         if config['serial']:
             # --------------------------------------------------------
             # SERIAL
             # --------------------------------------------------------
-            if _debug:
-                print('  serial')
+            logger.partitioning('  serial')
 
             if config['readonly']:
-                if _debug:
-                    print('   readonly=True')
+                logger.partitioning('   readonly=True')
 
                 if originally_on_disk:
-                    if _debug:
-                        print('    subarray originally on disk')
+                    logger.partitioning('    subarray originally on disk')
 
                     if config.get('to_disk', False):
                         # 1.1.1.1 The original subarray was on disk,
@@ -816,17 +813,15 @@ class Partition:
                         #         subarray in memory, and we are happy
                         #         to discard any changes that may have
                         #         been made to the subaray.
-                        if _debug:
-                            print('    1.1.1.1 revert')
+                        logger.partitioning('    1.1.1.1 revert')
                         self.revert()
-                    elif FREE_MEMORY() <= FM_THRESHOLD():
+                    elif free_memory() <= cf_fm_threshold():
                         # 1.1.1.2 The original subarray was on disk,
                         #         we are happy to keep the current
                         #         subarray in memory, but there is not
                         #         enough free memory to do so.
-                        if _debug:
-                            print('    1.1.1.2 revert ({} <= {})'.format(
-                                FREE_MEMORY(), FM_THRESHOLD()))
+                        logger.partitioning('    1.1.1.2 revert ({} <= {})'.format(
+                            free_memory(), cf_fm_threshold()))
                         self.revert()
                     else:
                         # 1.1.1.3 The original subarray was on disk
@@ -841,33 +836,30 @@ class Partition:
                                 original_subarray._partition_file)
 
                         del self.masked
-                        if _debug:
-                            print('    1.1.1.3 del masked ({} > {})'.format(
-                                FREE_MEMORY(), FM_THRESHOLD()))
+                        logger.partitioning(
+                            '    1.1.1.3 del masked ({} > {})'.format(
+                                free_memory(), cf_fm_threshold())
+                        )
 
                 else:
-                    if _debug:
-                        print('   subarray originally in memory')
+                    logger.partitioning('   subarray originally in memory')
                     if config.get('to_disk', False):
                         # 1.1.2.1 Original subarray was in memory and
                         #         we don't want to keep the current
                         #         subarray in memory
-                        if _debug:
-                            print('    1.1.2.1 to_disk')
+                        logger.partitioning('    1.1.2.1 to_disk')
                         self.to_disk(reopen=False)
-                    elif FREE_MEMORY() <= FM_THRESHOLD():
+                    elif free_memory() <= cf_fm_threshold():
                         # 1.1.2.2 Original subarray was in memory and
                         #         unique but there is not enough
                         #         memory to keep the current subarray
-                        if _debug:
-                            print('    1.1.2.2 to_disk')
+                        logger.partitioning('    1.1.2.2 to_disk')
                         self.to_disk(reopen=False)
                     else:
                         # 1.1.2.3 Original subarray was in memory and
                         #         unique and there is enough memory to
                         #         keep the current subarray in memory
-                        if _debug:
-                            print('    1.1.2.3 pass')
+                        logger.partitioning('    1.1.2.3 pass')
                         pass
             else:
                 # config['readonly'] is False
@@ -884,10 +876,9 @@ class Partition:
                             _remove_temporary_files(
                                 original_subarray._partition_file)
 
-                        if _debug:
-                            print('    1.2.1.1 to_disk')
+                        logger.partitioning('    1.2.1.1 to_disk')
                         self.to_disk(reopen=False)
-                    elif FREE_MEMORY() <= FM_THRESHOLD():
+                    elif free_memory() <= cf_fm_threshold():
                         # 1.2.1.2 Original subarray was on disk but
                         #         there is not enough memory to keep
                         #         it
@@ -899,39 +890,32 @@ class Partition:
                             _remove_temporary_files(
                                 original_subarray._partition_file)
 
-                        if _debug:
-                            print('    1.2.1.2 to_disk')
+                        logger.partitioning('    1.2.1.2 to_disk')
                         self.to_disk(reopen=False)
                     else:
                         # 1.2.1.3 Original subarray was on disk and
                         #         there is enough memory to keep it
-                        if _debug:
-                            print('    1.2.1.3 pass')
+                        logger.partitioning('    1.2.1.3 pass')
                         del self.masked
-                        pass
                 else:
                     if config.get('to_disk', False):
                         # 1.2.2.1 Original subarray was in memory but
                         #         we don't want to keep it
-                        if _debug:
-                            print('    1.2.2.1 to_disk')
+                        logger.partitioning('    1.2.2.1 to_disk')
                         self.to_disk(reopen=False)
-                    elif FREE_MEMORY() <= FM_THRESHOLD():
+                    elif free_memory() <= cf_fm_threshold():
                         # 1.2.2.2 Original subarray was an in memory
                         #         but there is not enough memory to
                         #         keep it
-                        if _debug:
-                            print('    1.2.2.2 to_disk')
+                        logger.partitioning('    1.2.2.2 to_disk')
                         self.to_disk(reopen=False)
                     else:
                         # 1.2.2.3 Original subarray was in memory and
                         #         there is enough memory to keep it
-                        if _debug:
-                            print('    1.2.2.3 del masked')
+                        logger.partitioning('    1.2.2.3 del masked')
                         del self.masked
         else:
-            if _debug:
-                print('Partition.close: parallel')
+            logger.partitioning('Partition.close: parallel')
             # --------------------------------------------------------
             # PARALLEL
             # --------------------------------------------------------
@@ -1766,7 +1750,7 @@ class Partition:
         '''
 #        try:
         tfa = CachedArray(self.array)
-#        except:
+#        except Exception:
 #            return False
 
         fd, _lock_file = mkstemp(prefix=tfa._partition_file + '_',
@@ -1809,7 +1793,7 @@ class Partition:
 #
 #        try:
 #            self.subarray = SharedMemoryArray(self.array)
-#        except:
+#        except Exception:
 #            return False
 #
 #        # Re-open the partition
