@@ -40,7 +40,7 @@ class DimensionCoordinate(mixin.Coordinate,
     The dimension coordinate construct consists of a data array of the
     coordinate values which spans a subset of the domain axis
     constructs, an optional array of cell bounds recording the extents
-    of each cell (stored in a `cf.Bounds` object), and properties to
+    of each cell (stored in a `Bounds` object), and properties to
     describe the coordinates. An array of cell bounds spans the same
     domain axes as its coordinate array, with the addition of an extra
     dimension whose size is that of the number of vertices of each
@@ -56,6 +56,10 @@ class DimensionCoordinate(mixin.Coordinate,
     `nc_set_variable`, `nc_get_variable`, `nc_del_variable` and
     `nc_has_variable` methods.
 
+    The netCDF variable group structure may be accessed with the
+    `nc_set_variable`, `nc_get_variable`, `nc_variable_groups`,
+    `nc_clear_variable_groups` and `nc_set_variable_groups` methods.
+
     '''
     def __repr__(self):
         '''Called by the `repr` built-in function.
@@ -231,21 +235,6 @@ class DimensionCoordinate(mixin.Coordinate,
         '''
         return self.direction()
 
-    @property
-    def isdimension(self):
-        '''True, denoting that the variable is a dimension coordinate object.
-
-    .. seealso::`isauxiliary`, `isdomainancillary`, `isfieldancillary`,
-                `ismeasure`
-
-    **Examples:**
-
-    >>> c.isdimension
-    True
-
-        '''
-        return True
-
 #    @property
 #    def lower_bounds(self):
 #        '''The lower dimension coordinate bounds in a `cf.Data` object.
@@ -648,7 +637,7 @@ class DimensionCoordinate(mixin.Coordinate,
         return bounds
 
     @_deprecated_kwarg_check('i')
-    @_inplace_enabled
+    @_inplace_enabled(default=False)
     def flip(self, axes=None, inplace=False, i=False):
         '''TODO
         '''
@@ -672,9 +661,10 @@ class DimensionCoordinate(mixin.Coordinate,
     :Parameters:
 
         default: optional
-            Return the value of the default parameter if bounds have
-            not been set. If set to an `Exception` instance then it
-            will be raised instead.
+            Return the value of the *default* parameter if bounds have
+            not been set.
+
+            {{default Exception}}
 
     :Returns:
 
@@ -772,9 +762,9 @@ class DimensionCoordinate(mixin.Coordinate,
 #        return True
 
     @_deprecated_kwarg_check('i')
-    @_inplace_enabled
+    @_inplace_enabled(default=False)
     def roll(self, axis, shift, inplace=False, i=False):
-        '''TODO
+        '''TODO `{{class}}`
 
         '''
         if self.size <= 1:
@@ -851,7 +841,7 @@ class DimensionCoordinate(mixin.Coordinate,
     # ----------------------------------------------------------------
     @property
     def role(self):
-        '''Deprecated at version 3.0.0. Use attribute 'construct_type'
+        '''Deprecated at version 3.0.0, use `construct_type` attribute
     instead.
 
         '''
