@@ -10,4 +10,4 @@ def example_field(n, _implementation=_implementation):
     return cfdm.example_field(n, _implementation=_implementation)
 
 
-example_field.__doc__ = cfdm.example_field.__doc__
+example_field.__doc__ = cfdm.example_field.__doc__.replace('cfdm.', 'cf.')
