@@ -1,14 +1,25 @@
 from copy import copy
 
+import logging
+
+import cfdm
+
+from .mixin_container import Container
+
 from .functions import (_DEPRECATION_ERROR,
                         _DEPRECATION_ERROR_KWARGS,
                         _DEPRECATION_ERROR_METHOD,
                         _DEPRECATION_ERROR_DICT)
 
-from .decorators import _deprecated_kwarg_check
+from .decorators import (_deprecated_kwarg_check,
+                         _manage_log_level_via_verbosity)
 
 
-class FieldList(list):
+logger = logging.getLogger(__name__)
+
+
+class FieldList(list,
+                cfdm.Container):
     '''An ordered sequence of fields.
 
     Each element of a field list is a field construct.
@@ -49,6 +60,8 @@ class FieldList(list):
              Create a new field list with these fields.
 
         '''
+        super(cfdm.Container, self).__init__()
+
         if fields is not None:
             if getattr(fields, 'construct_type', None) == 'field':
                 self.append(fields)
@@ -71,6 +84,30 @@ class FieldList(list):
         out = ',\n '.join(out)
         return '['+out+']'
 
+    def __str__(self):
+        '''Called by the `str` built-in function.
+
+    x.__str__() <==> str(x)
+
+        '''
+        return repr(self)
+
+    def __docstring_method_exclusions__(self):
+        '''Return the names of methods to exclude from docstring
+    substitutions.
+
+    See `_docstring_method_exclusions` for details.
+
+        '''
+        return (
+            'append',
+            'extend',
+            'insert',
+            'pop',
+            'reverse',
+            'clear',
+        )
+
     # ----------------------------------------------------------------
     # Overloaded list methods
     # ----------------------------------------------------------------
@@ -206,14 +243,14 @@ class FieldList(list):
         return not self.equals(other)
 
     # ???
-    __len__     = list.__len__
+    __len__ = list.__len__
     __setitem__ = list.__setitem__
-    append      = list.append
-    extend      = list.extend
-    insert      = list.insert
-    pop         = list.pop
-    reverse     = list.reverse
-    sort        = list.sort
+    append = list.append
+    extend = list.extend
+    insert = list.insert
+    pop = list.pop
+    reverse = list.reverse
+    sort = list.sort
 
     # ----------------------------------------------------------------
     # Methods
@@ -441,7 +478,8 @@ class FieldList(list):
         return type(self)([f.copy(data=data) for f in self])
 
     @_deprecated_kwarg_check('traceback')
-    def equals(self, other, rtol=None, atol=None, verbose=False,
+    @_manage_log_level_via_verbosity
+    def equals(self, other, rtol=None, atol=None, verbose=None,
                ignore_data_type=False, ignore_fill_value=False,
                ignore_properties=(), ignore_compression=False,
                ignore_type=False, ignore=(), traceback=False,
@@ -472,11 +510,7 @@ class FieldList(list):
       type, the same missing data mask, and be element-wise equal (see
       the *ignore_data_type* parameter).
 
-    Two real numbers ``x`` and ``y`` are considered equal if
-    ``|x-y|<=atol+rtol|y|``, where ``atol`` (the tolerance on absolute
-    differences) and ``rtol`` (the tolerance on relative differences)
-    are positive, typically very small numbers. See the *atol* and
-    *rtol* parameters.
+    {{equals tolerance}}
 
     If data arrays are compressed then the compression type and the
     underlying compressed arrays must be the same, as well as the
@@ -491,24 +525,16 @@ class FieldList(list):
         other:
             The object to compare for equality.
 
-        atol: float, optional
-            The tolerance on absolute differences between real
-            numbers. The default value is set by the `cfdm.ATOL`
-            function.
+        {{atol: number, optional}}
 
-        rtol: float, optional
-            The tolerance on relative differences between real
-            numbers. The default value is set by the `cfdm.RTOL`
-            function.
+        {{rtol: number, optional}}
 
         ignore_fill_value: `bool`, optional
             If `True` then the "_FillValue" and "missing_value"
             properties are omitted from the comparison, for the field
             construct and metadata constructs.
 
-        verbose: `bool`, optional
-            If `True` then print information about differences that lead
-            to inequality.
+        {{verbose: `int` or `str` or `None`, optional}}
 
         ignore_properties: sequence of `str`, optional
             The names of properties of the field construct (not the
@@ -516,25 +542,9 @@ class FieldList(list):
             that the "Conventions" property is always omitted by
             default.
 
-        ignore_data_type: `bool`, optional
-            If `True` then ignore the data types in all numerical
-            comparisons. By default different numerical data types
-            imply inequality, regardless of whether the elements are
-            within the tolerance for equality.
+        {{ignore_data_type: `bool`, optional}}
 
-        ignore_compression: `bool`, optional
-            If `True` then any compression applied to underlying arrays
-            is ignored and only uncompressed arrays are tested for
-            equality. By default the compression type and, if
-            applicable, the underlying compressed arrays must be the
-            same, as well as the arrays in their uncompressed forms
-
-        ignore_type: `bool`, optional
-            Any type of object may be tested but, in general, equality
-            is only possible with another field list, or a subclass of
-            one. If *ignore_type* is True then
-            ``FieldList(source=other)`` is tested, rather than the
-            ``other`` defined by the *other* parameter.
+        {{ignore_compression: `bool`, optional}}
 
         unordered: `bool`, optional
             TODO
@@ -571,23 +581,21 @@ class FieldList(list):
             if not isinstance(other, self.__class__):
                 other = type(self)(source=other, copy=False)
         elif not isinstance(other, self.__class__):
-            if verbose:
-                print(
-                    "{0}: Incompatible type: {1}".format(
-                        self.__class__.__name__, other.__class__.__name__)
-                )  # pragma: no cover
+            logger.info(
+                "{0}: Incompatible type: {1}".format(
+                    self.__class__.__name__, other.__class__.__name__)
+            )  # pragma: no cover
             return False
 
         # Check that there are equal numbers of fields
         len_self = len(self)
         if len_self != len(other):
-            if verbose:
-                print(
-                    "{0}: Different numbers of field construct: "
-                    "{1}, {2}".format(
-                        self.__class__.__name__,
-                        len_self, len(other))
-                )  # pragma: no cover
+            logger.info(
+                "{0}: Different numbers of field construct: "
+                "{1}, {2}".format(
+                    self.__class__.__name__,
+                    len_self, len(other))
+            )  # pragma: no cover
             return False
 
         if not unordered or len_self == 1:
@@ -602,12 +610,11 @@ class FieldList(list):
                                 ignore_data_type=ignore_data_type,
                                 ignore_type=ignore_type,
                                 verbose=verbose):
-                    if verbose:
-                        print(
-                            "{0}: Different field constructs at element {1}: "
-                            "{2!r}, {3!r}".format(
-                                self.__class__.__name__, i, f, g)
-                        )  # pragma: no cover
+                    logger.info(
+                        "{0}: Different field constructs at element {1}: "
+                        "{2!r}, {3!r}".format(
+                            self.__class__.__name__, i, f, g)
+                    )  # pragma: no cover
                     return False
         else:
             # ----------------------------------------------------
@@ -624,11 +631,10 @@ class FieldList(list):
 
             # Check that there are the same identities
             if set(self_identity) != set(other_identity):
-                if verbose:
-                    print("{}: Different sets of identities: {}, {}".format(
-                        self.__class__.__name__,
-                        set(self_identity),
-                        set(other_identity)))  # pragma: no cover
+                logger.info("{}: Different sets of identities: {}, {}".format(
+                    self.__class__.__name__,
+                    set(self_identity),
+                    set(other_identity)))  # pragma: no cover
                 return False
 
             # Check that there are the same number of variables
@@ -636,16 +642,15 @@ class FieldList(list):
             for identity, fl in self_identity.items():
                 gl = other_identity[identity]
                 if len(fl) != len(gl):
-                    if verbose:
-                        print(
-                            "{0}: Different numbers of {1!r} {2}s: "
-                            "{3}, {4}".format(
-                                self.__class__.__name__,
-                                identity,
-                                fl[0].__class__.__name__,
-                                len(fl), len(gl)
-                            )
-                        )  # pragma: no cover
+                    logger.info(
+                        "{0}: Different numbers of {1!r} {2}s: "
+                        "{3}, {4}".format(
+                            self.__class__.__name__,
+                            identity,
+                            fl[0].__class__.__name__,
+                            len(fl), len(gl)
+                        )
+                    )  # pragma: no cover
                     return False
             # --- End: for
 
@@ -670,12 +675,11 @@ class FieldList(list):
                 # --- End: for
 
                 if not found_match:
-                    if verbose:
-                        print(
-                            "{0}: No {1} equal to: {2!r}".format(
-                                self.__class__.__name__,
-                                g.__class__.__name__, f)
-                        )  # pragma: no cover
+                    logger.info(
+                        "{0}: No {1} equal to: {2!r}".format(
+                            self.__class__.__name__,
+                            g.__class__.__name__, f)
+                    )  # pragma: no cover
                     return False
         # --- End: if
 
@@ -997,7 +1001,7 @@ class FieldList(list):
 
         return type(self)(f for f in self if f.match_by_rank(*ranks))
 
-    def select_by_ncvar(self, *rank):
+    def select_by_ncvar(self, *ncvars):
         '''Select field constructs by netCDF variable name.
 
     To find the inverse of the selection, use a list comprehension
@@ -1040,7 +1044,27 @@ class FieldList(list):
 
     **Examples:**
 
-    TODO
+    >>> fl = cf.FieldList([cf.example_field(0), cf.example_field(1)])
+    >>> fl
+    [<CF Field: specific_humidity(latitude(5), longitude(8)) 1>,
+     <CF Field: air_temperature(atmosphere_hybrid_height_coordinate(1), grid_latitude(10), grid_longitude(9)) K>]
+    >>> f[0].nc_get_variable()
+    'humidity'
+    >>> f[1].nc_get_variable()
+    'temp'
+
+    >>> fl.select_by_ncvar('humidity')
+    [<CF Field: specific_humidity(cf_role=timeseries_id(4), ncdim%timeseries(9))>]
+    >>> fl.select_by_ncvar('humidity', 'temp')
+    [<CF Field: specific_humidity(cf_role=timeseries_id(4), ncdim%timeseries(9))>,
+     <CF Field: air_temperature(cf_role=timeseries_id(4), ncdim%timeseries(9)) Celsius>]
+    >>> fl.select_by_ncvar()
+    [<CF Field: specific_humidity(cf_role=timeseries_id(4), ncdim%timeseries(9))>,
+     <CF Field: air_temperature(cf_role=timeseries_id(4), ncdim%timeseries(9)) Celsius>]
+
+    >>> import re
+    >>> fl.select_by_ncvar(re.compile('^hum'))
+    [<CF Field: specific_humidity(cf_role=timeseries_id(4), ncdim%timeseries(9))>]
 
         '''
         return type(self)(f for f in self if f.match_by_ncvar(*ncvars))
