@@ -1,15 +1,20 @@
 from copy import deepcopy
 
-from ..functions import ATOL, RTOL
+from ..functions import (atol as cf_atol,
+                         rtol as cf_rtol)
 
 from ..query import Query
 from ..units import Units
 
+from ..data import Data
+
 from ..functions import (_DEPRECATION_ERROR_METHOD,
                          _DEPRECATION_ERROR)
 
+from ..mixin_container import Container
 
-class Properties:
+
+class Properties(Container):
     '''Mixin class for a container of descriptive properties.
 
     .. versionadded:: 3.0.0
@@ -17,28 +22,40 @@ class Properties:
     '''
     _special_properties = ()
 
+    def __new__(cls, *args, **kwargs):
+        '''Store component classes.
+
+    .. note:: If a child class requires a different component classes
+              than the ones defined here, then they must be redefined
+              in the child class.
+
+        '''
+        instance = super().__new__(cls)
+        instance._Data = Data
+        return instance
+
     # ----------------------------------------------------------------
     # Private attributes
     # ----------------------------------------------------------------
     @property
-    def _ATOL(self):
+    def _atol(self):
         '''Return the tolerance on absolute differences between real numbers,
-    as returned by the `cf.ATOL` function.
+    as returned by the `cf.atol` function.
 
     This is used by, for example, the `_equals` method.
 
         '''
-        return ATOL()
+        return cf_atol()
 
     @property
-    def _RTOL(self):
+    def _rtol(self):
         '''Return the tolerance on relative differences between real numbers,
-    as returned by the `cf.RTOL` function.
+    as returned by the `cf.rtol` function.
 
     This is used by, for example, the `_equals` method.
 
         '''
-        return RTOL()
+        return cf_rtol()
 
     # ----------------------------------------------------------------
     # Private methods
@@ -85,19 +102,27 @@ class Properties:
     # ----------------------------------------------------------------
     @property
     def id(self):
-        '''A canonical identity.
+        '''An identity for the {{class}} object.
 
     The `id` attribute can be used to unambiguously identify
-    constructs in the absence of a `standard_name` property.
+    constructs. This can be useful when identification is not possible
+    from the existing properties, either because they are missing or
+    because they do not provide sufficiently unique information.
 
-    Note that `id` is not a CF property and so is not read from, or
+    In general it will only be defined if explicitly set by the user.
+
+    Note that `id` is not a CF property and so is not read from, nor
     written to, datasets.
 
+    .. seealso:: `identity`, `identities`, `match_by_identity`
+
     **Examples:**
 
     >>> f.id = 'um01002'
     >>> f.id
     'um01002'
+    >>> f.match_by_identity('id%um10002')
+    True
     >>> del f.id
 
         '''
@@ -108,7 +133,8 @@ class Properties:
                 self.__class__.__name__))
 
     @id.setter
-    def id(self, value):   self._custom['id'] = value
+    def id(self, value):
+        self._custom['id'] = value
 
     @id.deleter
     def id(self):
@@ -536,8 +562,9 @@ class Properties:
 
         default: optional
             Return the value of the *default* parameter if the
-            property does not exist. If set to an `Exception` instance
-            then it will be raised instead.
+            property has not been set.
+
+            {{default Exception}}
 
     :Returns:
 
@@ -546,7 +573,7 @@ class Properties:
 
     **Examples:**
 
-
+    >>> f = cf.{{class}}()
     >>> f.set_property('project', 'CMIP7')
     >>> f.has_property('project')
     True
@@ -596,6 +623,7 @@ class Properties:
 
     **Examples:**
 
+    >>> f = cf.{{class}}()
     >>> f.set_property('project', 'CMIP7')
     >>> f.has_property('project')
     True
@@ -632,19 +660,21 @@ class Properties:
             The name of the property.
 
             *Parameter example:*
-               ``prop='long_name'``
+              ``prop='long_name'``
 
         default: optional
             Return the value of the *default* parameter if the
-            property does not exist. If set to an `Exception` instance
-            then it will be raised instead.
+            property has not been set.
 
-    :Returns:
+            {{default Exception}}
+
+     :Returns:
 
             The removed property.
 
     **Examples:**
 
+    >>> f = cf.{{class}}()
     >>> f.set_property('project', 'CMIP7')
     >>> f.has_property('project')
     True
@@ -1037,6 +1067,7 @@ class Properties:
 
     **Examples:**
 
+    >>> f = cf.{{class}}()
     >>> f.set_property('project', 'CMIP7')
     >>> f.has_property('project')
     True
@@ -1094,9 +1125,7 @@ class Properties:
     # Deprecated attributes and methods
     # ----------------------------------------------------------------
     def setprop(self, *args, **kwargs):
-        '''Delete a CF property.
-
-    Deprecated at version 3.0.0. Use method 'set_property' instead.
+        '''Deprecated at version 3.0.0, use method `set_property` instead.
 
         '''
         _DEPRECATION_ERROR_METHOD(
@@ -1104,9 +1133,7 @@ class Properties:
         )  # pragma: no cover
 
     def delprop(self, prop):
-        '''Delete a CF property.
-
-    Deprecated at version 3.0.0. Use method 'del_property' instead.
+        '''Deprecated at version 3.0.0, use method `del_property` instead.
 
         '''
         _DEPRECATION_ERROR_METHOD(
@@ -1114,9 +1141,7 @@ class Properties:
         )  # pragma: no cover
 
     def hasprop(self, prop):
-        '''Whether a property has been set.
-
-    Deprecated at version 3.0.0. Use method 'has_property' instead.
+        '''Deprecated at version 3.0.0, use method `has_property` instead.
 
         '''
         _DEPRECATION_ERROR_METHOD(
@@ -1124,9 +1149,7 @@ class Properties:
         )  # pragma: no cover
 
     def getprop(self, prop):
-        '''Get a property.
-
-    Deprecated at version 3.0.0. Use method 'get_property' instead.
+        '''Deprecated at version 3.0.0, use method `get_property` instead.
 
         '''
         _DEPRECATION_ERROR_METHOD(
