@@ -1,3 +1,5 @@
+import logging
+
 from operator import __and__ as operator_and
 from operator import __or__  as operator_or
 
@@ -5,17 +7,21 @@ from .functions  import equals  as _equals
 from .functions  import inspect as _inspect
 from .units      import Units
 
-from .data.data import Data
+from .data import Data
 
 from .functions  import (_DEPRECATION_ERROR_FUNCTION_KWARGS,
                          _DEPRECATION_ERROR_ATTRIBUTE,
                          _DEPRECATION_ERROR_FUNCTION)
 
-from .decorators import _deprecated_kwarg_check
+from .decorators import (_deprecated_kwarg_check,
+                         _manage_log_level_via_verbosity)
+
+
+logger = logging.getLogger(__name__)
 
 
 class Query:
-    '''Encapsulate a condition.
+    '''Encapsulate a condition for subsequent evaluation.
 
     A condition that may be applied to any object may be stored in a
     `Query` object. A `Query` object encapulates a condition, such as
@@ -65,7 +71,7 @@ class Query:
        >>> lt5 = cf.Query('lt', 5)
        >>> c = ge3 & lt5
        >>> c
-       >>> <CF Query: [(ge 3) & (lt 5)]>
+       <CF Query: [(ge 3) & (lt 5)]>
        >>> c == 2
        False
        >>> c != 2
@@ -487,58 +493,53 @@ class Query:
             return(string)
 
     @_deprecated_kwarg_check('traceback')
-    def equals(self, other, verbose=False, traceback=False):
+    @_manage_log_level_via_verbosity
+    def equals(self, other, verbose=None, traceback=False):
         '''TODO
 
         '''
         if self._compound:
             if not other._compound:
-                if verbose:
-                    print(
-                        "{}: Different compound components".format(
-                            self.__class__.__name__)
-                    )  # pragma: no cover
+                logger.info(
+                    "{}: Different compound components".format(
+                        self.__class__.__name__)
+                )  # pragma: no cover
                 return False
 
             if self._bitwise_operator != other._bitwise_operator:
-                if verbose:
-                    print(
-                        "{}: Different compound operators: {!r}, {!r}".format(
-                            self.__class__.__name__, self._bitwise_operator,
-                            other._bitwise_operator
-                        )
-                    )  # pragma: no cover
+                logger.info(
+                    "{}: Different compound operators: {!r}, {!r}".format(
+                        self.__class__.__name__, self._bitwise_operator,
+                        other._bitwise_operator
+                    )
+                )  # pragma: no cover
                 return False
 
             if not self._compound[0].equals(other._compound[0]):
                 if not self._compound[0].equals(other._compound[1]):
-                    if verbose:
-                        print(
-                            "{}: Different compound components".format(
-                                self.__class__.__name__)
-                        )  # pragma: no cover
-                    return False
-                if not self._compound[1].equals(other._compound[0]):
-                    if verbose:
-                        print(
-                            "{}: Different compound components".format(
-                                self.__class__.__name__)
-                        )  # pragma: no cover
-                    return False
-            elif not self._compound[1].equals(other._compound[1]):
-                if verbose:
-                    print(
+                    logger.info(
                         "{}: Different compound components".format(
                             self.__class__.__name__)
                     )  # pragma: no cover
-                return False
-
-        elif other._compound:
-            if verbose:
-                print(
+                    return False
+                if not self._compound[1].equals(other._compound[0]):
+                    logger.info(
+                        "{}: Different compound components".format(
+                            self.__class__.__name__)
+                    )  # pragma: no cover
+                    return False
+            elif not self._compound[1].equals(other._compound[1]):
+                logger.info(
                     "{}: Different compound components".format(
                         self.__class__.__name__)
                 )  # pragma: no cover
+                return False
+
+        elif other._compound:
+            logger.info(
+                "{}: Different compound components".format(
+                    self.__class__.__name__)
+            )  # pragma: no cover
             return False
 
         for attr in ('_NotImplemented_RHS_Data_op',
@@ -548,14 +549,13 @@ class Query:
             if not _equals(getattr(self, attr, None),
                            getattr(other, attr, None),
                            verbose=verbose):
-                if verbose:
-                    print(
-                        "{}: Different {!r} attributes: {!r}, {!r}".format(
-                            self.__class__.__name__, attr,
-                            getattr(self, attr, None),
-                            getattr(other, attr, None)
-                        )
-                    )  # pragma: no cover
+                logger.info(
+                    "{}: Different {!r} attributes: {!r}, {!r}".format(
+                        self.__class__.__name__, attr,
+                        getattr(self, attr, None),
+                        getattr(other, attr, None)
+                    )
+                )  # pragma: no cover
                 return False
         # --- End: for
 
@@ -1247,7 +1247,7 @@ def contains(value, units=None):
     <CF Query: [lower_bounds(le 8) & upper_bounds(ge 8)]>
     >>> cf.contains(30, 'degrees_east')
     <CF Query: [lower_bounds(le 30 degrees_east) & upper_bounds(ge 30 degrees_east)]>
-    >>>  cf.contains(cf.Data(10, 'km'))
+    >>> cf.contains(cf.Data(10, 'km'))
     <CF Query: [lower_bounds(le 10 km) & upper_bounds(ge 10 km)]>
 
     >>> c
