@@ -116,6 +116,14 @@ class NetCDFRead(cfdm.read_write.netcdf.NetCDFRead):
 
     :Parameters:
 
+        ncvar: `str`
+            The name of the netCDF variable that contains the data.
+
+        construct: optional
+
+        unpacked_dtype: `False` or `numpy.dtype`, optional
+
+        uncompress_override: `bool`, optional
 
     :Returns:
 
@@ -137,7 +145,7 @@ class NetCDFRead(cfdm.read_write.netcdf.NetCDFRead):
                 construct=construct,
                 unpacked_dtype=unpacked_dtype,
                 uncompress_override=uncompress_override,
-                parent_ncvar=parent_ncvar
+                parent_ncvar=parent_ncvar,
             )
 
         # ------------------------------------------------------------
@@ -176,7 +184,6 @@ class NetCDFRead(cfdm.read_write.netcdf.NetCDFRead):
 
         # UNICODE???? TODO
         if self._is_char(ncvar) and dtype.kind in 'SU' and ncdimensions:
-            # strlen = len(nc.dimensions[ncdimensions[-1]])
             strlen = g['nc'].dimensions[ncdimensions[-1]].size
             if strlen > 1:
                 ncdimensions.pop()
@@ -185,13 +192,10 @@ class NetCDFRead(cfdm.read_write.netcdf.NetCDFRead):
 
         cfa_data['dtype'] = dtype
         cfa_data['_axes'] = ncdimensions
-#        cfa_data['shape'] = [len(nc.dimensions[ncdim])
-#                             for ncdim in ncdimensions]
         cfa_data['shape'] = [g['nc'].dimensions[ncdim].size
                              for ncdim in ncdimensions]
 
         for attrs in cfa_data['Partitions']:
-
             # FORMAT
             sformat = attrs.get('subarray', {}).pop('format', 'netCDF')
             if sformat is not None:
@@ -257,6 +261,11 @@ class NetCDFRead(cfdm.read_write.netcdf.NetCDFRead):
 
     .. versionadded:: 3.0.0
 
+    :Parameters:
+
+        ncvar: `str`
+            The netCDF variable from which to get units and calendar.
+
         '''
         try:
             compressed = array.get_compression_type()  # TODO
@@ -318,7 +327,7 @@ class NetCDFRead(cfdm.read_write.netcdf.NetCDFRead):
                     g['variable_dimensions'][ncvar] = tuple(
                         map(str, ncdimensions))
 
-    def file_open(self, filename):
+    def file_open(self, filename, flatten=True, verbose=None):
         '''Open the netCDf file for reading.
 
     :Paramters:
@@ -326,13 +335,19 @@ class NetCDFRead(cfdm.read_write.netcdf.NetCDFRead):
         filename: `str`
             The netCDF file to be read.
 
+        flatten: `bool`, optional
+            If False then do not flatten a grouped file. Ignored if
+            the file has no groups.
+
+            .. versionadded:: 3.6.0
+
     :Returns:
 
         `netCDF4.Dataset`
             The object for the file.
 
         '''
-        out = super().file_open(filename)
+        out = super().file_open(filename, flatten=flatten, verbose=verbose)
         _file_to_fh['netCDF'].pop(filename, None)
         return out
 
