@@ -1252,7 +1252,7 @@ string_char_file = _make_string_char_file('string_char.nc')
 
 
 if __name__ == '__main__':
-    print('Run date:', datetime.datetime.utcnow())
-    print(cf.environment(display=False))
+    print('Run date:', datetime.datetime.now())
+    print(cf.environment())
     print()
     unittest.main(verbosity=2)
