@@ -1,6 +1,5 @@
 import datetime
 import os
-import time
 import unittest
 
 import numpy
@@ -9,24 +8,24 @@ import cf
 
 
 class DimensionCoordinateTest(unittest.TestCase):
-    def setUp(self):
-        self.filename = os.path.join(
-            os.path.dirname(os.path.abspath(__file__)), 'test_file.nc')
+    filename = os.path.join(
+        os.path.dirname(os.path.abspath(__file__)), 'test_file.nc')
 
-        dim1 = cf.DimensionCoordinate()
-        dim1.standard_name = 'latitude'
-        a = numpy.array(
-            [-30, -23.5, -17.8123, -11.3345, -0.7, -0.2, 0, 0.2, 0.7, 11.30003,
-             17.8678678, 23.5, 30]
-        )
-        dim1.set_data(cf.Data(a, 'degrees_north'))
-        bounds = cf.Bounds()
-        b = numpy.empty(a.shape + (2,))
-        b[:, 0] = a - 0.1
-        b[:, 1] = a + 0.1
-        bounds.set_data(cf.Data(b))
-        dim1.set_bounds(bounds)
-        self.dim = dim1
+#    f = cf.read(filename)[0]
+
+    dim = cf.DimensionCoordinate()
+    dim.standard_name = 'latitude'
+    a = numpy.array(
+        [-30, -23.5, -17.8123, -11.3345, -0.7, -0.2, 0, 0.2, 0.7, 11.30003,
+         17.8678678, 23.5, 30]
+    )
+    dim.set_data(cf.Data(a, 'degrees_north'))
+    bounds = cf.Bounds()
+    b = numpy.empty(a.shape + (2,))
+    b[:, 0] = a - 0.1
+    b[:, 1] = a + 0.1
+    bounds.set_data(cf.Data(b))
+    dim.set_bounds(bounds)
 
     def test_DimensionCoordinate__repr__str__dump(self):
         f = cf.read(self.filename)[0]
@@ -36,8 +35,6 @@ class DimensionCoordinateTest(unittest.TestCase):
         _ = str(x)
         _ = x.dump(display=False)
 
-        self.assertTrue(x.isdimension)
-
     def test_DimensionCoordinate_convert_reference_time(self):
         d = cf.DimensionCoordinate()
         d.set_data(
@@ -141,9 +138,8 @@ class DimensionCoordinateTest(unittest.TestCase):
                 self.assertTrue((g_rolled.array == g_rolled_0.array).all())
 
             for index in range(0, 10):  # check all elements are rolled
-                self.assertTrue(
-                    g_rolled.array[0, index, 0] == g.array[0, index, -shift_by]
-                )
+                self.assertEqual(g_rolled.array[0, index, 0],
+                                 g.array[0, index, -shift_by])
 
     def test_DimensionCoordinate_cellsize(self):
         d = self.dim.copy()
@@ -231,30 +227,30 @@ class DimensionCoordinateTest(unittest.TestCase):
         x = f.dimension_coordinates('X').value()
 
         x.positive = 'up'
-        self.assertTrue(x.positive == 'up')
+        self.assertEqual(x.positive, 'up')
         del x.positive
 
         x.axis = 'Z'
-        self.assertTrue(x.axis == 'Z')
+        self.assertEqual(x.axis, 'Z')
         del x.axis
 
         x.axis = 'T'
-        self.assertTrue(x.ndim == 1)
+        self.assertEqual(x.ndim, 1)
 
     def test_DimensionCoordinate_insert_dimension(self):
         f = cf.read(self.filename)[0]
         x = f.dimension_coordinates('X').value()
 
-        self.assertTrue(x.shape == (9,))
-        self.assertTrue(x.bounds.shape == (9, 2))
+        self.assertEqual(x.shape, (9,))
+        self.assertEqual(x.bounds.shape, (9, 2))
 
         y = x.insert_dimension(0)
-        self.assertTrue(y.shape == (1, 9))
-        self.assertTrue(y.bounds.shape == (1, 9, 2), y.bounds.shape)
+        self.assertEqual(y.shape, (1, 9))
+        self.assertEqual(y.bounds.shape, (1, 9, 2), y.bounds.shape)
 
         x.insert_dimension(-1, inplace=True)
-        self.assertTrue(x.shape == (9, 1))
-        self.assertTrue(x.bounds.shape == (9, 1, 2), x.bounds.shape)
+        self.assertEqual(x.shape, (9, 1))
+        self.assertEqual(x.bounds.shape, (9, 1, 2), x.bounds.shape)
 
     def test_DimensionCoordinate_binary_operation(self):
         f = cf.read(self.filename)[0]
@@ -331,9 +327,30 @@ class DimensionCoordinateTest(unittest.TestCase):
         x += 2
         self.assertTrue((x.array == (d+2)*2 + 2).all())
 
+    def test_DimensionCoordinate_set_data(self):
+        x = cf.DimensionCoordinate()
+
+        y = x.set_data(cf.Data([1, 2, 3]))
+        self.assertIsNone(y)
+        self.assertTrue(x.has_data())
+
+        # Test inplace
+        x.del_data()
+        y = x.set_data(cf.Data([1, 2, 3]), inplace=False)
+        self.assertIsInstance(y, cf.DimensionCoordinate)
+        self.assertFalse(x.has_data())
+        self.assertTrue(y.has_data())
+
+        # Exceptions should be raised for 0-d and N-d (N>=2) data
+        with self.assertRaises(Exception):
+            y = x.set_data(cf.Data([[1, 2, 3]]))
+
+        with self.assertRaises(Exception):
+            y = x.set_data(cf.Data(1))
 
 # --- End: class
 
+
 if __name__ == "__main__":
     print('Run date:', datetime.datetime.now())
     cf.environment()
