@@ -1,6 +1,4 @@
 import datetime
-import os
-import time
 import unittest
 
 import numpy
@@ -11,17 +9,16 @@ import cf
 class DomainAncillaryTest(unittest.TestCase):
     def test_DomainAncillary(self):
         f = cf.DomainAncillary()
-        self.assertTrue(f.isdomainancillary)
 
         _ = repr(f)
         _ = str(f)
         _ = f.dump(display=False)
 
-
 # --- End: class
 
+
 if __name__ == '__main__':
-    print('Run date:', datetime.datetime.utcnow())
+    print('Run date:', datetime.datetime.now())
     cf.environment()
     print()
     unittest.main(verbosity=2)
