@@ -1,6 +1,4 @@
 import datetime
-import os
-import time
 import unittest
 
 import cf
@@ -18,40 +16,39 @@ class DomainAxisTest(unittest.TestCase):
         x = cf.DomainAxis(size=111)
         x.nc_set_dimension('tas')
 
-        self.assertTrue(x.size == 111)
+        self.assertEqual(x.size, 111)
         del x.size
         self.assertIsNone(getattr(x, 'size', None))
         x.size = 56
-        self.assertTrue(x.size == 56)
-
-        self.assertTrue(x == 56)
+        self.assertEqual(x.size, 56)
+        self.assertEqual(x, 56)
 
         x += 1
-        self.assertTrue(x.size == 57)
+        self.assertEqual(x.size, 57)
         x -= 1
-        self.assertTrue(x.size == 56)
+        self.assertEqual(x.size, 56)
         y = x + 1
-        self.assertTrue(y.size == 57)
+        self.assertEqual(y.size, 57)
         y = x - 1
-        self.assertTrue(y.size == 55)
+        self.assertEqual(y.size, 55)
         y = 1 + x
-        self.assertTrue(y.size == 57)
+        self.assertEqual(y.size, 57)
 
-        self.assertTrue(int(x) == 56)
+        self.assertEqual(int(x), 56)
 
-        self.assertTrue(x > 1)
-        self.assertTrue(x < 100)
-        self.assertTrue(x >= 1)
-        self.assertTrue(x <= 100)
-        self.assertTrue(x != 100)
+        self.assertGreater(x, 1)
+        self.assertLess(x, 100)
+        self.assertGreaterEqual(x, 1)
+        self.assertLessEqual(x, 100)
+        self.assertNotEqual(x, 100)
 
         _ = hash(x)
 
-
 # --- End: class
 
+
 if __name__ == '__main__':
-    print('Run date:', datetime.datetime.utcnow())
+    print('Run date:', datetime.datetime.now())
     cf.environment()
     print()
     unittest.main(verbosity=2)
