@@ -1,7 +1,6 @@
 import datetime
 import inspect
 import os
-import sys
 import unittest
 
 import cf
@@ -11,7 +10,7 @@ class PartitionTest(unittest.TestCase):
     filename = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                             'test_file.nc')
     chunk_sizes = (17, 34, 300, 100000)[::-1]
-    original_chunksize = cf.CHUNKSIZE()
+    original_chunksize = cf.chunksize()
 
     test_only = []
 
@@ -19,7 +18,6 @@ class PartitionTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-
 # --- End: class
 
 
