@@ -1,6 +1,7 @@
 import datetime
 import os
 import unittest
+import warnings
 
 import cf
 
@@ -13,10 +14,10 @@ class aggregateTest(unittest.TestCase):
     file2 = os.path.join(
         os.path.dirname(os.path.abspath(__file__)), 'file2.nc')
 
-    chunk_sizes = (17, 34, 300, 100000)[::-1]
+    chunk_sizes = (100000, 300, 34)
     original_chunksize = cf.chunksize()
 
-    def test_aggregate(self):
+    def test_basic_aggregate(self):
         for chunksize in self.chunk_sizes:
             cf.chunksize(chunksize)
 
@@ -33,12 +34,25 @@ class aggregateTest(unittest.TestCase):
             g0 = g.copy()
             self.assertTrue(g.equals(g0, verbose=2), "g != g0")
 
-            h = cf.aggregate(g, verbose=2)
+            with warnings.catch_warnings():
+                # Suppress noise throughout the test fixture from:
+                #
+                #   ~/cf-python/cf/__init__.py:1459: FutureWarning: elementwise
+                #   comparison failed; returning scalar instead, but in the
+                #   future will perform elementwise comparison
+                #
+                # TODO: it is not clear where the above emerges from, e.g.
+                # since __init__ file ref'd does not have that many lines.
+                # It seems like this warning arises from NumPy comparisons
+                # done at some point in (only) some aggregate calls (see e.g:
+                # https://github.com/numpy/numpy/issues/6784).
+                warnings.filterwarnings('ignore', category=FutureWarning)
+                h = cf.aggregate(g, verbose=2)
 
-            self.assertTrue(len(h) == 1)
+            self.assertEqual(len(h), 1)
 
-            self.assertTrue(
-                h[0].shape == (10, 9),
+            self.assertEqual(
+                h[0].shape, (10, 9),
                 'h[0].shape = ' + repr(h[0].shape) + ' != (10, 9)'
             )
 
@@ -49,7 +63,9 @@ class aggregateTest(unittest.TestCase):
 
             self.assertTrue(h[0].equals(f, verbose=2), 'h[0] != f')
 
-            i = cf.aggregate(g, verbose=2)
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore", category=FutureWarning)
+                i = cf.aggregate(g, verbose=2)
 
             self.assertTrue(
                 i.equals(h, verbose=2),
@@ -61,7 +77,9 @@ class aggregateTest(unittest.TestCase):
                 'g != itself after the second aggregation'
             )
 
-            i = cf.aggregate(g, verbose=2, axes='grid_latitude')
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore", category=FutureWarning)
+                i = cf.aggregate(g, verbose=2, axes='grid_latitude')
 
             self.assertTrue(
                 i.equals(h, verbose=2),
@@ -73,13 +91,15 @@ class aggregateTest(unittest.TestCase):
                 'g !=itself after the third aggregation'
             )
 
-            self.assertTrue(
-                i[0].shape == (10, 9), 'i[0].shape is ' + repr(i[0].shape))
+            self.assertEqual(i[0].shape, (10, 9),
+                             'i[0].shape is ' + repr(i[0].shape))
 
-            i = cf.aggregate(
-                g, verbose=2, axes='grid_latitude',
-                donotchecknonaggregatingaxes=1
-            )
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore", category=FutureWarning)
+                i = cf.aggregate(
+                    g, verbose=2, axes='grid_latitude',
+                    donotchecknonaggregatingaxes=1
+                )
 
             self.assertTrue(
                 i.equals(h, verbose=2),
@@ -91,45 +111,65 @@ class aggregateTest(unittest.TestCase):
                 'g != itself after the fourth aggregation'
             )
 
-            self.assertTrue(
-                i[0].shape == (10, 9), 'i[0].shape is ' + repr(i[0].shape))
+            self.assertEqual(i[0].shape, (10, 9),
+                             'i[0].shape is ' + repr(i[0].shape))
 
-            #
             q, t = cf.read(self.file)
             c = cf.read(self.file2)[0]
 
             d = cf.aggregate([c, t], verbose=1, relaxed_identities=True)
             e = cf.aggregate([t, c], verbose=1, relaxed_identities=True)
 
-            self.assertTrue(len(d) == 1)
-            self.assertTrue(len(e) == 1)
-            self.assertTrue(d[0].shape == (3,) + t.shape)
+            self.assertEqual(len(d), 1)
+            self.assertEqual(len(e), 1)
+            self.assertEqual(d[0].shape, (3,) + t.shape)
             self.assertTrue(d[0].equals(e[0], verbose=2))
 
             x = cf.read(['file.nc', 'file2.nc'], aggregate=False)
-            self.assertTrue(len(x) == 3)
+            self.assertEqual(len(x), 3)
 
             x = cf.read(
                 ['file.nc', 'file2.nc'],
                 aggregate={'relaxed_identities': True}
             )
-            self.assertTrue(len(x) == 2)
+            self.assertEqual(len(x), 2)
 
             del t.standard_name
             del c.standard_name
             x = cf.aggregate([c, t])
-            self.assertTrue(len(x) == 2)
+            self.assertEqual(len(x), 2)
 
             t.long_name = 'qwerty'
             c.long_name = 'qwerty'
             x = cf.aggregate([c, t], field_identity='long_name')
-            self.assertTrue(len(x) == 1)
+            self.assertEqual(len(x), 1)
 
         cf.chunksize(self.original_chunksize)
 
+    def test_aggregate_exist_equal_ignore_opts(self):
+        # TODO: extend the option-checking coverage so all options and all
+        # reasonable combinations of them are tested. For now, this is
+        # testing options that previously errored due to a bug.
+        for chunksize in self.chunk_sizes:
+            cf.chunksize(chunksize)
+
+            f = cf.read(self.filename, squeeze=True)[0]
+
+            # Use f as-is: simple test that aggregate works and does not
+            # change anything with the given options:
+            g = cf.aggregate(f, exist_all=True)[0]
+            self.assertEqual(g, f)
+            h = cf.aggregate(f, equal_all=True)[0]
+            self.assertEqual(h, f)
+
+            with self.assertRaises(ValueError):  # contradictory options
+                cf.aggregate(f, exist_all=True, equal_all=True)
+
+        cf.chunksize(self.original_chunksize)
 
 # --- End: class
 
+
 if __name__ == "__main__":
     print('Run date:', datetime.datetime.now())
     cf.environment()
