@@ -1,7 +1,6 @@
 import datetime
 import tempfile
 import os
-import sys
 import numpy
 import unittest
 import atexit
@@ -9,8 +8,8 @@ import atexit
 import cf
 
 
-tmpfile = tempfile.mktemp('.nc')
-tmpfile2 = tempfile.mktemp('.nca')
+tmpfile = tempfile.mkstemp('.nc')[1]
+tmpfile2 = tempfile.mkstemp('.nca')[1]
 tmpfiles = [tmpfile, tmpfile2, 'delme.nc', 'delme.nca']
 
 
@@ -210,7 +209,7 @@ class generalTest(unittest.TestCase):
 # --- End: class
 
 if __name__ == "__main__":
-    print('Run date:', datetime.datetime.utcnow())
+    print('Run date:', datetime.datetime.now())
     cf.environment()
     print()
     unittest.main(verbosity=2)
