@@ -2,16 +2,16 @@ import atexit
 import datetime
 import os
 import tempfile
-import time
 import unittest
 
 import numpy
 
 import cf
 
-
-tmpfile = tempfile.mktemp('.cf_test')
-tmpfiles = [tmpfile]
+n_tmpfiles = 1
+tmpfiles = [tempfile.mkstemp('_test_pp.nc', dir=os.getcwd())[1]
+            for i in range(n_tmpfiles)]
+[tmpfile] = tmpfiles
 
 
 def _remove_tmpfiles():
@@ -40,23 +40,23 @@ class ppTest(unittest.TestCase):
             '1!24!SURFACE TEMPERATURE AFTER TIMESTEP  !Pa!!!NEW_NAME!!')
         text_file.close()
 
-        self.chunk_sizes = (17, 34, 300, 100000)[::-1]
-        self.original_chunksize = cf.CHUNKSIZE()
-        self.test_only = ()
+        self.chunk_sizes = (100000, 300, 34)
+        self.original_chunksize = cf.chunksize()
 
     def test_PP_load_stash2standard_name(self):
         f = cf.read(self.ppfilename)[0]
-        self.assertTrue(f.identity() == 'surface_temperature')
-        self.assertTrue(f.Units == cf.Units('K'))
+        self.assertEqual(f.identity(), 'surface_temperature')
+        self.assertEqual(f.Units, cf.Units('K'))
+
         for merge in (True, False):
             cf.load_stash2standard_name(self.new_table, merge=merge)
             f = cf.read(self.ppfilename)[0]
-            self.assertTrue(f.identity() == 'NEW_NAME')
-            self.assertTrue(f.Units == cf.Units('Pa'))
+            self.assertEqual(f.identity(), 'NEW_NAME')
+            self.assertEqual(f.Units, cf.Units('Pa'))
             cf.load_stash2standard_name()
             f = cf.read(self.ppfilename)[0]
-            self.assertTrue(f.identity() == 'surface_temperature')
-            self.assertTrue(f.Units == cf.Units('K'))
+            self.assertEqual(f.identity(), 'surface_temperature')
+            self.assertEqual(f.Units, cf.Units('K'))
 
         cf.load_stash2standard_name()
 
@@ -71,7 +71,7 @@ class ppTest(unittest.TestCase):
         array = f.array
 
         for chunksize in self.chunk_sizes:
-            cf.CHUNKSIZE(chunksize)
+            cf.chunksize(chunksize)
 
             f = cf.read(self.ppfilename)[0]
 
@@ -86,18 +86,18 @@ class ppTest(unittest.TestCase):
                 g = cf.read(tmpfile)[0]
 
                 self.assertTrue((f.array == array).all(),
-                                'Bad unpacking of WGDOS packed data')
+                                'Bad unpacking of PP WGDOS packed data')
 
                 self.assertTrue(f.equals(g, verbose=2),
-                                'Bad writing/reading. format='+fmt)
-
-        cf.CHUNKSIZE(self.original_chunksize)
+                                'Bad writing/reading. fmt='+fmt)
 
+        cf.chunksize(self.original_chunksize)
 
 # --- End: class
 
+
 if __name__ == '__main__':
-    print('Run date:', datetime.datetime.utcnow())
+    print('Run date:', datetime.datetime.now())
     cf.environment()
     print()
     unittest.main(verbosity=2)
