@@ -11,12 +11,18 @@ import numpy
 
 import cf
 
-tmpfile = tempfile.mktemp('.cf_test')
-tmpfileh = tempfile.mktemp('.cf_test')
-tmpfilec = tempfile.mktemp('.cf_test')
-tmpfile0 = tempfile.mktemp('.cf_test')
-tmpfile1 = tempfile.mktemp('.cf_test')
-tmpfiles = [tmpfile, tmpfileh, tmpfilec, tmpfile0, tmpfile1]
+
+n_tmpfiles = 6
+tmpfiles = [tempfile.mkstemp('_test_read_write.nc', dir=os.getcwd())[1]
+            for i in range(n_tmpfiles)]
+(
+    tmpfile,
+    tmpfileh,
+    tmpfilec,
+    tmpfile0,
+    tmpfile1,
+    tmpfile2,
+ ) = tmpfiles
 
 
 def _remove_tmpfiles():
@@ -37,10 +43,13 @@ class read_writeTest(unittest.TestCase):
     filename = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                             'test_file.nc')
 
+    broken_bounds = os.path.join(os.path.dirname(os.path.abspath(__file__)),
+                                 'broken_bounds.cdl')
+
     string_filename = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                                    'string_char.nc')
 
-    chunk_sizes = (17, 34, 300, 100000)[::-1]
+    chunk_sizes = (100000, 300)
     original_chunksize = cf.chunksize()
 
     test_only = []
@@ -56,7 +65,6 @@ class read_writeTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        tmpfile = tempfile.mktemp('.cf_test')
         tmpfiles.append(tmpfile)
 
         f = cf.example_field(0)
@@ -87,26 +95,26 @@ class read_writeTest(unittest.TestCase):
         cf.write(f, tmpfile)
 
         g = cf.read(tmpfile)[0]
-        self.assertTrue(numpy.ma.count(g.data.array) == N - 2)
+        self.assertEqual(numpy.ma.count(g.data.array), N - 2)
 
         g = cf.read(tmpfile, mask=False)[0]
-        self.assertTrue(numpy.ma.count(g.data.array) == N)
+        self.assertEqual(numpy.ma.count(g.data.array), N)
 
         g.apply_masking(inplace=True)
-        self.assertTrue(numpy.ma.count(g.data.array) == N - 2)
+        self.assertEqual(numpy.ma.count(g.data.array), N - 2)
 
         f.set_property('_FillValue', 999)
         f.set_property('missing_value', -111)
         cf.write(f, tmpfile)
 
         g = cf.read(tmpfile)[0]
-        self.assertTrue(numpy.ma.count(g.data.array) == N - 2)
+        self.assertEqual(numpy.ma.count(g.data.array), N - 2)
 
         g = cf.read(tmpfile, mask=False)[0]
-        self.assertTrue(numpy.ma.count(g.data.array) == N)
+        self.assertEqual(numpy.ma.count(g.data.array), N)
 
         g.apply_masking(inplace=True)
-        self.assertTrue(numpy.ma.count(g.data.array) == N - 2)
+        self.assertEqual(numpy.ma.count(g.data.array), N - 2)
 
     def test_read_directory(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
@@ -120,7 +128,7 @@ class read_writeTest(unittest.TestCase):
             os.mkdir(dir)
         except FileExistsError:
             pass
-        except:
+        except Exception:
             raise ValueError("Can not mkdir {}{}".format(pwd, dir))
 
         f = 'test_file2.nc'
@@ -134,7 +142,7 @@ class read_writeTest(unittest.TestCase):
             os.mkdir(subdir)
         except FileExistsError:
             pass
-        except:
+        except Exception:
             raise ValueError("Can not mkdir {}{}".format(pwd, subdir))
 
         for f in ('test_file3.nc', 'test_file.nc'):
@@ -145,25 +153,25 @@ class read_writeTest(unittest.TestCase):
         # --- End: for
 
         f = cf.read(dir, aggregate=False)
-        self.assertTrue(len(f) == 1, f)
+        self.assertEqual(len(f), 1, f)
 
         f = cf.read(dir, recursive=True, aggregate=False)
-        self.assertTrue(len(f) == 3, f)
+        self.assertEqual(len(f), 3, f)
 
         f = cf.read([dir, subdir], aggregate=False)
-        self.assertTrue(len(f) == 3, f)
+        self.assertEqual(len(f), 3, f)
 
         f = cf.read([subdir, dir], aggregate=False)
-        self.assertTrue(len(f) == 3, f)
+        self.assertEqual(len(f), 3, f)
 
         f = cf.read([dir, subdir], recursive=True, aggregate=False)
-        self.assertTrue(len(f) == 5, f)
+        self.assertEqual(len(f), 5, f)
 
         f = cf.read(subdir, aggregate=False)
-        self.assertTrue(len(f) == 2, f)
+        self.assertEqual(len(f), 2, f)
 
         f = cf.read(subdir, recursive=True, aggregate=False)
-        self.assertTrue(len(f) == 2, f)
+        self.assertEqual(len(f), 2, f)
 
         shutil.rmtree(dir)
 
@@ -203,67 +211,65 @@ class read_writeTest(unittest.TestCase):
         filename = self.filename
 
         f = cf.read(filename)
-        self.assertTrue(len(f) == 1, '\n'+str(f))
+        self.assertEqual(len(f), 1, '\n'+str(f))
 
         f = cf.read(filename, extra=['auxiliary_coordinate'])
-        self.assertTrue(len(f) == 4, '\n'+str(f))
+        self.assertEqual(len(f), 4, '\n'+str(f))
 
         f = cf.read(filename, extra='cell_measure')
-        self.assertTrue(len(f) == 2, '\n'+str(f))
+        self.assertEqual(len(f), 2, '\n'+str(f))
 
         f = cf.read(filename, extra=['field_ancillary'])
-        self.assertTrue(len(f) == 5, '\n'+str(f))
+        self.assertEqual(len(f), 5, '\n'+str(f))
 
         f = cf.read(filename, extra='domain_ancillary', verbose=0)
-        self.assertTrue(len(f) == 4, '\n'+str(f))
+        self.assertEqual(len(f), 4, '\n'+str(f))
 
         f = cf.read(filename, extra=['field_ancillary',
                                      'auxiliary_coordinate'])
-        self.assertTrue(len(f) == 8, '\n'+str(f))
+        self.assertEqual(len(f), 8, '\n'+str(f))
 
-        self.assertTrue(len(cf.read(filename,
-                                    extra=['domain_ancillary',
-                                           'auxiliary_coordinate'])) == 7)
+        self.assertEqual(len(cf.read(filename,
+                                     extra=['domain_ancillary',
+                                            'auxiliary_coordinate'])), 7)
         f = cf.read(filename, extra=['domain_ancillary', 'cell_measure',
                                      'auxiliary_coordinate'])
-        self.assertTrue(len(f) == 8, '\n'+str(f))
+        self.assertEqual(len(f), 8, '\n'+str(f))
 
         f = cf.read(filename, extra=('field_ancillary', 'dimension_coordinate',
                                      'cell_measure', 'auxiliary_coordinate',
                                      'domain_ancillary'))
-        self.assertTrue(len(f) == 15, '\n'+str(f))
+        self.assertEqual(len(f), 15, '\n'+str(f))
 
     def test_read_write_format(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        for string in (True, False):
-            for chunksize in self.chunk_sizes:
-                cf.chunksize(chunksize)
-                for fmt in ('NETCDF3_CLASSIC',
-                            'NETCDF3_64BIT',
-                            'NETCDF3_64BIT_OFFSET',
-                            'NETCDF3_64BIT_DATA',
-                            'NETCDF4',
-                            'NETCDF4_CLASSIC',
-                            'CFA',):
-                    # print (fmt, string)
-                    f = cf.read(self.filename)[0]
-                    f0 = f.copy()
-                    cf.write(f, tmpfile, fmt=fmt, verbose=0, string=string)
-                    g = cf.read(tmpfile, verbose=0)
-                    self.assertTrue(len(g) == 1, 'g = '+repr(g))
-                    g0 = g[0]
+        for chunksize in self.chunk_sizes:
+            cf.chunksize(chunksize)
+            for fmt in ('NETCDF3_CLASSIC',
+                        'NETCDF3_64BIT',
+                        'NETCDF3_64BIT_OFFSET',
+                        'NETCDF3_64BIT_DATA',
+                        'NETCDF4',
+                        'NETCDF4_CLASSIC',
+                        'CFA',):
+                # print (fmt, string)
+                f = cf.read(self.filename)[0]
+                f0 = f.copy()
+                cf.write(f, tmpfile, fmt=fmt)
+                g = cf.read(tmpfile, verbose=0)
+                self.assertEqual(len(g), 1, 'g = '+repr(g))
+                g0 = g[0]
 
-                    self.assertTrue(
-                        f0.equals(g0, verbose=1),
-                        'Bad read/write of format {!r}'.format(fmt))
+                self.assertTrue(
+                    f0.equals(g0, verbose=1),
+                    'Bad read/write of format {!r}'.format(fmt))
 
     def test_read_write_netCDF4_compress_shuffle(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        tmpfile = tempfile.mktemp('.cf_test')
         tmpfiles.append(tmpfile)
 
         for chunksize in self.chunk_sizes:
@@ -272,8 +278,8 @@ class read_writeTest(unittest.TestCase):
             for fmt in ('NETCDF4',
                         'NETCDF4_CLASSIC',
                         'CFA4'):
-                for shuffle in (True, False):
-                    for compress in (4,):  # range(10):
+                for shuffle in (True,):
+                    for compress in (1,):  # range(10):
                         cf.write(f, tmpfile, fmt=fmt,
                                  compress=compress,
                                  shuffle=shuffle)
@@ -290,39 +296,37 @@ class read_writeTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
-        tmpfile = tempfile.mktemp('.cf_test')
         tmpfiles.append(tmpfile)
 
         for chunksize in self.chunk_sizes:
             cf.chunksize(chunksize)
             f = cf.read(self.filename)[0]
-            self.assertTrue(f.dtype == numpy.dtype(float))
+            self.assertEqual(f.dtype, numpy.dtype(float))
             cf.write(f, tmpfile, fmt='NETCDF4',
                      datatype={numpy.dtype(float): numpy.dtype('float32')})
             g = cf.read(tmpfile)[0]
-            self.assertTrue(g.dtype == numpy.dtype('float32'),
-                            'datatype read in is '+str(g.dtype))
+            self.assertEqual(g.dtype, numpy.dtype('float32'),
+                             'datatype read in is ' + str(g.dtype))
 
         cf.chunksize(self.original_chunksize)
 
         # Keyword single
         f = cf.read(self.filename)[0]
-        self.assertTrue(f.dtype == numpy.dtype(float))
+        self.assertEqual(f.dtype, numpy.dtype(float))
         cf.write(f, tmpfile, fmt='NETCDF4', single=True)
         g = cf.read(tmpfile)[0]
-        self.assertTrue(g.dtype == numpy.dtype('float32'),
-                        'datatype read in is '+str(g.dtype))
+        self.assertEqual(g.dtype, numpy.dtype('float32'),
+                         'datatype read in is ' + str(g.dtype))
 
-        tmpfile2 = tempfile.mktemp('.cf_test')
         tmpfiles.append(tmpfile2)
 
         # Keyword double
         f = g
-        self.assertTrue(f.dtype == numpy.dtype('float32'))
+        self.assertEqual(f.dtype, numpy.dtype('float32'))
         cf.write(f, tmpfile2, fmt='NETCDF4', double=True)
         g = cf.read(tmpfile2)[0]
-        self.assertTrue(g.dtype == numpy.dtype(float),
-                        'datatype read in is '+str(g.dtype))
+        self.assertEqual(g.dtype, numpy.dtype(float),
+                         'datatype read in is ' + str(g.dtype))
 
         for single in (True, False):
             for dousble in (True, False):
@@ -345,8 +349,9 @@ class read_writeTest(unittest.TestCase):
             for chunksize in self.chunk_sizes:
                 cf.chunksize(chunksize)
                 f = cf.read(self.filename)[0]
-                t = cf.DimensionCoordinate(data=cf.Data(
-                    123, 'days since 1750-1-1'))
+                t = cf.DimensionCoordinate(
+                    data=cf.Data([123], 'days since 1750-1-1')
+                )
 
                 t.standard_name = 'time'
                 axisT = f.set_construct(cf.DomainAxis(1))
@@ -355,26 +360,13 @@ class read_writeTest(unittest.TestCase):
                          reference_datetime=reference_datetime)
                 g = cf.read(tmpfile)[0]
                 t = g.dimension_coordinate('T')
-                self.assertTrue(
-                    t.Units == cf.Units('days since ' + reference_datetime),
+                self.assertEqual(
+                    t.Units, cf.Units('days since ' + reference_datetime),
                     ('Units written were ' + repr(t.Units.reftime)
                      + ' not ' + repr(reference_datetime)))
         # --- End: for
         cf.chunksize(self.original_chunksize)
 
-#    def test_write_HDF_chunks(self):
-#        if self.test_only and inspect.stack()[0][3] not in self.test_only:
-#            return
-#
-#        for chunksize in self.chunk_sizes:
-#            for fmt in ('NETCDF3_CLASSIC', 'NETCDF4'):
-#                cf.chunksize(chunksize)
-#                f = cf.read(self.filename)[0]
-#                f.HDF_chunks({'T': 10000, 1: 3, 'grid_lat': 222, 45:45})
-#                cf.write(f, tmpfile, fmt=fmt, HDF_chunksizes={'X': 6})
-#        # --- End: for
-#        cf.chunksize(self.original_chunksize)
-
     def test_read_write_unlimited(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
@@ -457,32 +449,28 @@ class read_writeTest(unittest.TestCase):
             self.assertTrue(f[j].data.equals(f[i].data, verbose=1),
                             "{!r} {!r}".format(f[j], f[i]))
 
+        f0 = cf.read(self.string_filename)
         for string0 in (True, False):
             for fmt0 in ('NETCDF4',
-                         'NETCDF3_CLASSIC',
-                         'NETCDF4_CLASSIC',
-                         'NETCDF3_64BIT',
-                         'NETCDF3_64BIT_OFFSET',
-                         'NETCDF3_64BIT_DATA'):
-                # print ('fmt0=', fmt0)
-                f0 = cf.read(self.string_filename)
+                         'NETCDF3_CLASSIC'):
                 cf.write(f0, tmpfile0, fmt=fmt0, string=string0)
 
                 for string1 in (True, False):
                     for fmt1 in ('NETCDF4',
-                                 'NETCDF3_CLASSIC',
-                                 'NETCDF4_CLASSIC',
-                                 'NETCDF3_64BIT',
-                                 'NETCDF3_64BIT_OFFSET',
-                                 'NETCDF3_64BIT_DATA'):
-                        # print ('fmt1=', fmt1)
-                        f1 = cf.read(self.string_filename)
+                                 'NETCDF3_CLASSIC'):
                         cf.write(f0, tmpfile1, fmt=fmt1, string=string1)
 
                         for i, j in zip(cf.read(tmpfile1), cf.read(tmpfile0)):
                             self.assertTrue(i.equals(j, verbose=1))
         # --- End: for
 
+    def test_read_broken_bounds(self):
+        if self.test_only and inspect.stack()[0][3] not in self.test_only:
+            return
+
+        f = cf.read(self.broken_bounds, verbose=0)
+        self.assertEqual(len(f), 2)
+
 # --- End: class
 
 
