@@ -1,3 +1,5 @@
+import logging
+
 from operator import __add__, __sub__
 
 from collections import namedtuple
@@ -11,22 +13,26 @@ from .units      import Units
 
 from .data.data import Data
 
-from .decorators import _deprecated_kwarg_check
+from .decorators import (_deprecated_kwarg_check,
+                         _manage_log_level_via_verbosity)
 
 
+logger = logging.getLogger(__name__)
+
 # Define some useful units
-_calendar_years  = Units('calendar_years')
+_calendar_years = Units('calendar_years')
 _calendar_months = Units('calendar_months')
-_days            = Units('days')
-_hours           = Units('hours')
-_minutes         = Units('minutes')
-_seconds         = Units('seconds')
+_days = Units('days')
+_hours = Units('hours')
+_minutes = Units('minutes')
+_seconds = Units('seconds')
 
 # Define some useful constants
-_one_year   = Data(1, 'calendar_years')
-_one_day    = Data(1, 'day')
-_one_hour   = Data(1, 'hour')
+_one_year = Data(1, 'calendar_years')
+_one_day = Data(1, 'day')
+_one_hour = Data(1, 'hour')
 _one_minute = Data(1, 'minute')
+_one_second = Data(1, 'second')
 
 # Default month lengths in days
 _default_month_lengths = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31]
@@ -268,9 +274,22 @@ class TimeDuration:
 
          month, day, hour, minute, second: `int` or `None`, optional
             The offset used when creating, with the `bounds` method, a
-            time interval containing a given date-time. Only the
-            offset elements for units smaller that of the time
-            duration are used.
+            time interval containing a given date-time.
+
+            .. note:: The offset element *month* is ignored unless the
+                      time duration is at least 1 calendar year.
+
+                      The offset element *day* is ignored unless the
+                      time duration is at least 1 calendar month.
+
+                      The offset element *hour* is ignored unless the
+                      time duration is at least 1 day
+
+                      The offset element *minute* is ignored unless
+                      the time duration is at least 1 hour.
+
+                      The offset element *second* is ignored unless
+                      the time duration is at least 1 minute
 
             *Parameter example:*
               >>> cf.TimeDuration(1, 'calendar_month').bounds(
@@ -325,12 +344,18 @@ class TimeDuration:
         else:
             offset[1] = None
             offset[2] = None
-            if units <= _hours and duration < _one_day:
+            if duration < _one_day:
                 offset[3] = None
-                if units <= _minutes and duration < _one_hour:
+                if duration < _one_hour:
                     offset[4] = None
-                    if units <= _seconds and duration < _one_minute:
+                    if duration < _one_minute:
                         offset[5] = None
+#            if units <= _hours and duration < _one_day:
+#                offset[3] = None
+#                if units <= _minutes and duration < _one_hour:
+#                    offset[4] = None
+#                    if units <= _seconds and duration < _one_minute:
+#                        offset[5] = None
         # --- End: if
         self.offset = Offset(*offset)
 
@@ -690,7 +715,7 @@ class TimeDuration:
     def __rsub__(self, other):
         '''The binary arithmetic operation ``-`` with reflected operands
 
-    x.__rsub__(y) <==> y-x
+    x.__rsub__(y) <==> y - x
 
     .. versionadded:: 1.4
 
@@ -702,7 +727,7 @@ class TimeDuration:
             # other is a date-time object
             try:
                 return self._datetime_arithmetic(other, __sub__)
-            except:
+            except TypeError:
                 return NotImplemented
 
         return NotImplemented
@@ -792,6 +817,15 @@ class TimeDuration:
 
     .. versionadded:: 1.4
 
+    :Parameters:
+
+        other: any object with a `timetuple` method
+
+        op: `str`
+
+    :Returns:
+
+
         '''
         def _dHMS(duration, other, calendar, op):
             units = Units(
@@ -808,23 +842,23 @@ class TimeDuration:
             months = int(months0)
             if months != months0:
                 raise ValueError(
-                    "Fractional months not supported for date calculations: "
-                    "{}".format(months0)
+                    "Fractional months are not supported for  "
+                    "date calculations: {}".format(months0)
                 )
         elif units == _calendar_months:
             months0 = duration.datum()
             months = int(months0)
             if months != months0:
                 raise ValueError(
-                    "Fractional months not supported for date calculations: "
-                    "{}".format(months0)
+                    "Fractional months are not supported for "
+                    "date calculations: {}".format(months0)
                 )
         else:
             months = None
 
         calendar = getattr(other, 'calendar', None)
-        if calendar == '':
-            calendar = None
+#        if calendar == '':
+#            calendar = None
 
         if months is not None:
             y, m = divmod(op(other.month, months), 12)
@@ -834,12 +868,23 @@ class TimeDuration:
 
             y = other.year + y
 
-            max_days = self.days_in_month(y, m, calendar)
             d = other.day
-            if d > max_days:
-                d = max_days
+            if calendar != '':
+                max_days = self.days_in_month(y, m, calendar)
+                if d > max_days:
+                    d = max_days
+            # --- End: if
 
-            return other.replace(year=y, month=m, day=d)
+            # TODO When cftime==1.1.4 is ready use this one line:
+#            return other.replace(year=y, month=m, day=d)
+            # Instead of these try ... except ... lines:
+            try:
+                return other.replace(year=y, month=m, day=d, calendar=calendar)
+            except (ValueError, TypeError):
+                # If we are here, then 'other' is a datetime.datetime
+                # object, which doesn't have a 'calendar' keyword to
+                # its 'replace' method.
+                return other.replace(year=y, month=m, day=d)
         else:
             return _dHMS(duration, other, calendar, op)
 
@@ -1013,15 +1058,18 @@ class TimeDuration:
     :Parameters:
 
         year: `int`
+            TODO
 
         month: `int`
+            TODO
 
         calendar: `str`, optional
             By default, calendar is the mixed Gregorian/Julian
             calendar as defined by Udunits.
 
         leap_month: `int`, optional
-            By default, the leap month is 2.
+            The leap month. By default the leap month is 2, i.e. the
+            seond month of the year.
 
         month_lengths: sequence of `int`, optional
             By default, *month_lengths* is ``[31, 28, 31, 30, 31, 30,
@@ -1068,7 +1116,8 @@ class TimeDuration:
         return length
 
     @_deprecated_kwarg_check('traceback')
-    def equals(self, other, rtol=None, atol=None, verbose=False,
+    @_manage_log_level_via_verbosity
+    def equals(self, other, rtol=None, atol=None, verbose=None,
                traceback=False):
         '''True if two time durations are equal.
 
@@ -1083,11 +1132,11 @@ class TimeDuration:
 
         atol: `float`, optional
             The absolute tolerance for all numerical comparisons, By
-            default the value returned by the `ATOL` function is used.
+            default the value returned by the `atol` function is used.
 
         rtol: `float`, optional
             The relative tolerance for all numerical comparisons, By
-            default the value returned by the `RTOL` function is used.
+            default the value returned by the `rtol` function is used.
 
         traceback: `bool`, optional
             If True then print a traceback highlighting where the two
@@ -1115,11 +1164,10 @@ class TimeDuration:
 
         # Check that each instance is the same type
         if self.__class__ != other.__class__:
-            if verbose:  # pragma: no cover
-                print(
-                    "%s: Different type: %s" % (
-                        self.__class__.__name__, other.__class__.__name__)
-                )  # pragma: no cover
+            logger.info(
+                "%s: Different type: %s" % (
+                    self.__class__.__name__, other.__class__.__name__)
+            )  # pragma: no cover
             return False
 
         self__dict__ = self.__dict__.copy()
@@ -1129,26 +1177,25 @@ class TimeDuration:
         d1 = other__dict__.pop('duration', None)
 
         if not d0.equals(d1):
-            if verbose:  # pragma: no cover
-                print(
-                    "%s: Different durations: %r, %r" % (
-                        self.__class__.__name__, d0, d1)
-                )  # pragma: no cover
+            logger.info(
+                "%s: Different durations: %r, %r" % (
+                    self.__class__.__name__, d0, d1)
+            )  # pragma: no cover
             return False
 
         if self__dict__ != other__dict__:
-            if verbose:  # pragma: no cover
-                print(
-                    "%s: Different The default date-time elements: "
-                    "%r != %r" % (
-                        self.__class__.__name__, self__dict__, other__dict__)
-                )  # pragma: no cover
+            logger.info(
+                "%s: Different default date-time elements: "
+                "%r != %r" % (
+                    self.__class__.__name__, self__dict__, other__dict__)
+            )  # pragma: no cover
             return False
 
         return True
 
     @_deprecated_kwarg_check('traceback')
-    def equivalent(self, other, rtol=None, atol=None, verbose=True,
+    @_manage_log_level_via_verbosity
+    def equivalent(self, other, rtol=None, atol=None, verbose=None,
                    traceback=False):
         '''True if two time durations are logically equivalent.
 
@@ -1163,11 +1210,11 @@ class TimeDuration:
 
         atol: `float`, optional
             The absolute tolerance for all numerical comparisons, By
-            default the value returned by the `ATOL` function is used.
+            default the value returned by the `atol` function is used.
 
         rtol: `float`, optional
             The relative tolerance for all numerical comparisons, By
-            default the value returned by the `RTOL` function is used.
+            default the value returned by the `rtol` function is used.
 
         traceback: `bool`, optional
             If True then print a traceback highlighting where the two
@@ -1197,11 +1244,10 @@ class TimeDuration:
 
         # Check that each instance is the same type
         if self.__class__ != other.__class__:
-            if verbose:  # pragma: no cover
-                print(
-                    "%s: Different type: %s" % (
-                        self.__class__.__name__, other.__class__.__name__)
-                )  # pragma: no cover
+            logger.info(
+                "%s: Different type: %s" % (
+                    self.__class__.__name__, other.__class__.__name__)
+            )  # pragma: no cover
             return False
 
         self__dict__ = self.__dict__.copy()
@@ -1210,20 +1256,18 @@ class TimeDuration:
         d0 = self__dict__.pop('duration', None)
         d1 = other__dict__.pop('duration', None)
         if d0 != d0:
-            if verbose:  # pragma: no cover
-                print(
-                    "%s: Non-equivalent durations: %r, %r" % (
-                        self.__class__.__name__, d0, d1)
-                )  # pragma: no cover
+            logger.info(
+                "%s: Non-equivalent durations: %r, %r" % (
+                    self.__class__.__name__, d0, d1)
+            )  # pragma: no cover
             return False
 
         if self__dict__ != other__dict__:
-            if verbose:  # pragma: no cover
-                print(
-                    "%s: Non-equivalent default date-time elements: "
-                    "%r != %r" % (
-                        self.__class__.__name__, self__dict__, other__dict__)
-                )  # pragma: no cover
+            logger.info(
+                "%s: Non-equivalent default date-time elements: "
+                "%r != %r" % (
+                    self.__class__.__name__, self__dict__, other__dict__)
+            )  # pragma: no cover
             return False
 
         return True
@@ -1449,6 +1493,8 @@ class TimeDuration:
     The interval spans the time duration and starts and ends at
     date-times consistent with the time duration's offset.
 
+    The offset of the time duration is used to modify the bounds.
+
     .. versionadded:: 1.2.3
 
     .. seealso:: `cf.dt`, `cf.Datetime`, `interval` TODO
